@@ -12,4 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+"""Flask extension for APScheduler."""
+
+from flask_apscheduler.exceptions import ConfigurationError
 from flask_apscheduler.scheduler import APScheduler
