@@ -1,14 +1,16 @@
 import json
 
 from collections import OrderedDict
-from flask import current_app as app
+from flask import current_app
 from flask import jsonify
 from flask import Response
 from flask_apscheduler.utils import job_to_dict
 
 
 def get_job(job_id):
-    job = app.apscheduler.scheduler.get_job(job_id)
+    """Gets the specified job."""
+
+    job = current_app.apscheduler.scheduler.get_job(job_id)
 
     if job:
         return Response(json.dumps(job_to_dict(job), indent=2), mimetype='application/json')
@@ -17,7 +19,9 @@ def get_job(job_id):
 
 
 def get_jobs():
-    jobs = app.apscheduler.scheduler.get_jobs()
+    """Gets all jobs scheduled."""
+
+    jobs = current_app.apscheduler.scheduler.get_jobs()
 
     job_states = []
 
@@ -28,7 +32,9 @@ def get_jobs():
 
 
 def run_job(job_id):
-    job = app.apscheduler.scheduler.get_job(job_id)
+    """Executes the specified job."""
+
+    job = current_app.apscheduler.scheduler.get_job(job_id)
 
     if not job:
         response = jsonify(error_message='Job %s not found' % job_id)
@@ -45,9 +51,13 @@ def run_job(job_id):
 
 
 def get_scheduler_info():
+    """Gets the scheduler info."""
+
+    scheduler = current_app.apscheduler
+
     d = OrderedDict()
-    d['current_host'] = app.apscheduler.host_name
-    d['allowed_hosts'] = app.apscheduler.allowed_hosts
-    d['running'] = app.apscheduler.running
+    d['current_host'] = scheduler.host_name
+    d['allowed_hosts'] = scheduler.allowed_hosts
+    d['running'] = scheduler.running
 
     return Response(json.dumps(d, indent=2), mimetype='application/json')
